Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
expo_notifications/__init__.py | 0 | 0 | 0 | 100%
expo_notifications/admin.py | 73 | 15 | 0 | 79%
expo_notifications/apps.py | 5 | 0 | 0 | 100%
expo_notifications/conf.py | 22 | 1 | 0 | 95%
expo_notifications/managers/__init__.py | 4 | 0 | 0 | 100%
expo_notifications/managers/device_manager.py | 11 | 3 | 0 | 73%
expo_notifications/managers/message_manager.py | 27 | 16 | 1 | 41%
expo_notifications/managers/ticket_manager.py | 9 | 4 | 0 | 56%
expo_notifications/migrations/0001_initial.py | 8 | 8 | 0 | 0%
expo_notifications/migrations/__init__.py | 0 | 0 | 0 | 100%
expo_notifications/models/__init__.py | 5 | 0 | 0 | 100%
expo_notifications/models/device.py | 15 | 1 | 0 | 93%
expo_notifications/models/message.py | 31 | 4 | 0 | 87%
expo_notifications/models/receipt.py | 8 | 1 | 0 | 88%
expo_notifications/models/ticket.py | 17 | 4 | 0 | 76%
expo_notifications/tasks/__init__.py | 3 | 0 | 0 | 100%
expo_notifications/tasks/check_receipts_task.py | 30 | 21 | 0 | 30%
expo_notifications/tasks/send_messages_task.py | 32 | 22 | 0 | 31%
expo_notifications/tasks/session.py | 6 | 1 | 0 | 83%
Total | 306 | 101 | 1 | 67%

No items found using the specified filter.